from symmetric import symmetric


@symmetric.router("/sample")
def some_function():
    """Greets the world."""
    return "Hello World!"


@symmetric.router("/add")
def another_function(a, b=372):
    """
    Adds :a and :b and returns the result of
    that operation.
    """
    return a + b



"""
Setup config file for PyPI deployment.
"""

import setuptools

from symmetric import __version__

with open("README.md", "r") as raw_readme:
    README = raw_readme.read()

setuptools.setup(
    name="symmetric",
    version=__version__,
    url="https://github.com/daleal/symmetric",
    project_urls={
        "Documentation": "https://github.com/daleal/symmetric",
        "Code": "https://github.com/daleal/symmetric",
        "Issue tracker": "https://github.com/daleal/symmetric/issues",
    },
    license="MIT License",
    author="Daniel Leal",
    author_email="dlleal@uc.cl",
    maintainer="daleal",
    maintainer_email="dlleal@uc.cl",
    description="A simple wrapper over Flask to speed up basic "
                "API deployments.",
    long_description=README,
    long_description_content_type="text/markdown",
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
    install_requires=[
        "flask>=1.1.1",
    ],
    entry_points={
        'console_scripts': [
            'symmetric=symmetric.command_line_interface:dispatcher'
        ],
    },
)
